#ifndef __GL_CAM_H_
#define __GL_CAM_H_

#include "Matrix4x4.h"
#include "Vec3.h"

#include <vector>

namespace ambenv {

  const int SMOOTHING_FRAMES = 20;

  const Real SMOOTHING_FACTOR = 0.4;
  const Real SMOOTHING_WEIGHT = 0.6;
  
  class GLCam {

  public:
    void updateInverse();
    double * getInverse();

    GLCam( const Vec3 & eye = Vec3( 100.0, 100.0, 0.0 ), 
	   const Vec3 & lookAt = Vec3(), 
	   const Vec3 & up = Vec3( 0.0, 1.0, 0.0 ) );

    void load() const;
    
    void setEye( const Vec3& eye );
    const Vec3 & getEye() const
    { 
      return( m_eye );
    }

    void setLookAt( const Vec3& lookAt, bool forceNow = false );
    const Vec3 & getLookAt() const 
    { 
      return( m_lookAt ); 
    }

    // -- orbit in XZ plane
    void orbitXZ( Real angle );
    void orbitXY( Real angle );

    void rotateXZ( Real angle );
    void rotateXY( Real angle );

    void dolly( Real amount );

    void translate( Real mx, Real my );

    Real getX() const
    { 
      return( m_eye.x() ); 
    }
    Real getY() const 
    { 
      return( m_eye.y() );
    }
    Real getZ() 
    { 
      return( m_eye.z() );
    }

    const Vec3 & getPos() const
    { 
      return( m_eye );
    }
    
    void drawShadowBox();

    const Vec3 & eye() const { return( m_eye ); }
    const Vec3 & lookAt() const { return( m_lookAt ); }
    const Vec3 & up() const { return( m_up ); }

  private:
    Vec3 m_eye;
    Vec3 m_lookAt;
    Vec3 m_up;
    double m_aCamInv[16];

    // -- smoothing stuff...
    Vec3 smoothCamera( const Vec3 & lookAt );

    std::vector<Vec3> m_lookAtHistory;
  };

}; /* namespace ambenv */

#endif /* __GL_CAM_H_ */
