#ifndef __LIGHT_H_
#define __LIGHT_H_

#include "Nameable.h"
#include "Vec3.h"
#include "Ray.h"
#include "Transformable.h"

#include <string>

namespace ambenv {

  class Light : public Transformable, public Nameable {
  public:
    Light();
    Light( const std::string & name,
	   const Vec3 & ambient, const Vec3 & diffuse, const Vec3 & specular );

    virtual ~Light();

    // -- accessors
    Vec3 ambient() const;
    Vec3 diffuse() const;
    Vec3 specular() const;

    void ambient( const Vec3 & ambient );
    void diffuse( const Vec3 & diffuse );
    void specular( const Vec3 & specular );

    virtual Vec3 attenuationCoeff() const;

    //! given a point, returns a ray to this light.
    /*! for point lights, this will be a ray to the light's position.
     * for directional lights, this will be a ray opposed to the light's direction .
     */
    virtual Vec3 getVectorFrom( const Vec3 & point ) const;

  private:
    Vec3 m_ambient;
    Vec3 m_diffuse;
    Vec3 m_specular;
  };

}; /* namespace ambenv */

#endif /* __LIGHT_H_ */



