#include "Material.h"

#include <math.h>
#include <cassert>

using namespace ambenv;

Material::Material()
{
}

Material::Material( const std::string & name, const Vec3 & emission,
		    const Vec3 & ambient, const Vec3 & diffuse, const Vec3 & specular,
		    const Real specular_power, const std::string & texture )
  : m_emission( emission ), m_ambient( ambient ), m_diffuse( diffuse ),
    m_specular( specular ), m_specular_power( specular_power ), m_texture( texture ),
    m_materialId( 0 )
{
  Nameable::setName( name );
}

Material::~Material()
{
}


// -- get accessors
Vec3 Material::emission() const
{
  return( m_emission );
}
Vec3 Material::ambient() const
{
  return( m_ambient );
}
Vec3 Material::diffuse() const
{
  return( m_diffuse );
}
Vec3 Material::specular() const
{
  return( m_specular );
}
Real Material::specular_power() const
{
  return( m_specular_power );
}
std::string Material::texture() const
{
  return( m_texture );
}
unsigned Material::materialId() const
{
  return( m_materialId );
}

// -- set accessors
void Material::emission( const Vec3 & emission )
{
  m_emission = emission;
}
void Material::ambient( const Vec3 & ambient )
{
  m_ambient = ambient;
}
void Material::diffuse( const Vec3 & diffuse )
{
  m_diffuse = diffuse;
}
void Material::specular( const Vec3 & specular )
{
  m_specular = specular;
}
void Material::specular_power( const Real specular_power )
{
  m_specular_power = specular_power;
}
void Material::texture( const std::string & texture )
{
  m_texture = texture;
}
void Material::materialId( unsigned id )
{
  m_materialId = id;
}







