#ifndef __SCENE_H_
#define __SCENE_H_

#include "Camera.h"
#include "Instance.h"
#include "Light.h"
#include "LogMessage.h"
#include "Material.h"
#include "Mesh.h"
#include "Object.h"
#include "Texture.h"

#include <list>
#include <map>
#include <vector>
#include <string>

namespace ambenv {

  class Scene {
  public:
    Scene();
    ~Scene();

    void clear();

    void getBoundingBox( Vec3 * box );

    bool load3DS( const std::string & filename );
    bool load3dsNode( void * vp_file, void * vp_node, Mesh * mnode );
    bool load3dsTextures( const std::string & filename );

    std::list<Camera *> cameras;
    std::list<Light *> lights;
    std::list<Instance *> instances;
    std::map<std::string, Object *> objects;
    std::map<std::string, Material *> materials;    
    std::map<std::string, Texture *> textures;

    Vec3 Background;
    
    unsigned width;
    unsigned height;
    unsigned bpp;
    bool fullscreen;
    unsigned samples;
    bool usehemicube;
    
    std::vector<std::string> input_files;
    std::string outfile;

    LogMessage log;
  };  
}; /* namespace ambenv */

#endif /* __SCENE_H_ */
